@@ -179,8 +179,9 @@ sub response_handle {
 	my ($content_type, $body) = $self->views->{$t->response_view || $self->response_view} 
 		? $t->view($t->response_view || $self->response_view)->render($t, $response_body) 
 		: ($ct, $response_body->serialize());
+	$body = undef if $response_body->error && $response_body->no_response;
 	$res = $t->_build_response($sid, $content_type, $response_body->status_code ||= $status ||= 200);
-	$res->body($body);
+	$res->body($body) if $body;
 	return $res->finalize;
 }
 
@@ -266,7 +267,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.119
+Version 0.120
 
 =cut
 
